@@ -1,3 +1,5 @@
+from typing import Tuple
+
 from xdsl.ir import *
 
 
@@ -106,6 +108,36 @@ class Rewriter:
         op_pos = op_block.get_operation_index(op)
         Rewriter.inline_block_at_pos(block, op_block, op_pos + 1)
 
+    @staticmethod
+    def insert_block_after(block: Union[Block, List[Block]], target: Block):
+        """
+        Insert one or multiple blocks after another block.
+        The blocks to insert should be detached from any region.
+        The target block should not be contained in the block to insert.
+        """
+        if target.parent is None:
+            raise Exception("Cannot move a block after a toplevel op")
+        region = target.parent
+        block_list = block if isinstance(block, list) else [block]
+        if len(block_list) == 0:
+            return
+        pos = region.get_block_index(target)
+        region.insert_block(block_list, pos + 1)
+
+    @staticmethod
+    def insert_block_before(block: Union[Block, List[Block]], target: Block):
+        """
+        Insert one or multiple block before another block.
+        The blocks to insert should be detached from any region.
+        The target block should not be contained in the block to insert.
+        """
+        if target.parent is None:
+            raise Exception("Cannot move a block after a toplevel op")
+        region = target.parent
+        block_list = block if isinstance(block, list) else [block]
+        pos = region.get_block_index(target)
+        region.insert_block(block_list, pos)
+
     @staticmethod
     def move_region_contents_to_new_regions(region: Region) -> Region:
         """Move the region blocks to a new region."""
